<?php
/**
* This file specifices the form class.
*
* You can simple make a complete form by using the given functions. First you use <i>open_form()</i> to start a new form. Then you can use several input fields. At the end a <i>close_form()</i> is needed.
* There will be perhaps some more functions added.
* @package classes
*/
class form {

	/**
	* This function opens a new form with the given parameters.
	*
	* If you want to start a form, just use this function.
	* @param string <b>The name of the form.</b>
	* @param string <b>The action that will be performed when submitting the form.</b>
	* @param string <b>The method that should the form use. Normally POST or GET.</b>
	* @param string Can be used for formatting the form with style, class or id.
	* @return string Returns the open form tag.
	*/
	function open_form() {
	  $numargs = func_num_args();
	  switch($numargs-1) {
	  	case 0:
	  	case 1: return "You need at least the first 3 arguments.";
	  							break;
	  	case 2: return "<form name=\"". func_get_arg(0) ."\" action=\"". func_get_arg(1) ."\" method=\"". func_get_arg(2) ."\">\n";
	  							break;
	  	case 3: return "<form name=\"". func_get_arg(0) ."\" action=\"". func_get_arg(1) ."\" method=\"". func_get_arg(2) ."\" ". func_get_arg(3).">\n";
	  							break;
	  	}
	}
	
   /**
   * This function close a open form.
   *
   * Always close an open form with this function. If you forget this, your form properly won't work.
   * @return string Returns the close form tag. 
   */
	function close_form() {
		return "</form>\n";
	}
  
	/**
	* This function creates a new input field.
	*
	* The function can handle 5 parameters. Only one is always needed. But if you want to specify the type of the input field, you need all parameter! While you want to define a value for the field, you need the first 3 and so on...
	* @param string <b>Defines the name of the input field. The type is always text.</b>
	* @param int Defines the max. length of the text field.
	* @param string Defines the value of the input field. You can put prepared text here.
	* @param string Can define style, class or id within the input tag.
	* @param string Defines the type of the input field. Use only password, hidden or text!
	* @return string An input field with the given options.
	*/ 
  	function short_input() {
  	 	$numargs = func_num_args();
    	switch($numargs-1) {
    	case 0: return "<input name=\"". func_get_arg(0) ."\" type=\"text\" />\n";   
    					break;
    	case 1: return "<input name=\"". func_get_arg(0) ."\" type=\"text\" maxlength=\"". func_get_arg(1) ."\" />\n";
    					break;
    	case 2: return "<input name=\"". func_get_arg(0) ."\" type=\"text\" value=\"". func_get_arg(2) ."\" maxlength=\"". func_get_arg(1) ."\" />\n";
    					break;
    	case 3: return "<input name=\"". func_get_arg(0) ."\" value=\"". func_get_arg(2) ."\" maxlength=\"". func_get_arg(1) ."\" ".func_get_arg(3)." />\n";
    					break;
    	case 4: return "<input name=\"". func_get_arg(0) ."\" type=\"". func_get_arg(4) ."\" value=\"". func_get_arg(2) ."\" maxlength=\"". func_get_arg(1) ."\" ".func_get_arg(3)." />\n";
    					break;
    	}
	}
	
	/**
	* This function creates a textarea.
	*
	* The function can handle only 2 parameters. The first is always needed and the second is optional.
	* @param string <b>Defines the name of the textarea.</b>
	* @param string Fills the textarea with the given values.
	* @param string Can define style, class or id within the input tag.
	* @return string A textarea with the given options. 
	*/ 
  	function long_input() {
  	 	$numargs = func_num_args();
    	switch($numargs-1) {
    	case 0: return "<textarea name=\"". func_get_arg(0) ."\"></textarea><br />\n";
    					break;   	
    	case 1: return "<textarea name=\"". func_get_arg(0) ."\">". func_get_arg(1) ."</textarea><br />\n";
    					break;
    	case 2: return "<textarea name=\"". func_get_arg(0) ."\" ". func_get_arg(2) .">". func_get_arg(1) ."</textarea><br />\n";
   	}
  	}
	
	/**
	* The function button can create several buttons with different types, names and values.
	*
	* The function can handle 4 parameter. Only one is always needed. But if you want to define which type of input should be created, you need also a value. As you want to use the fourth parameter, you need all other, too.
	* @param string <b>Defines the name of the button. The value (label) is \"Submit\".</b>
	* @param string The value for the button.
	* @param string Defines which type of input this is. Only use checkbox, radio or submit!
	* @param String Can be used for the checkbox and radio field to be pre-selected by using selected or checked or for setting class/id for the button.
	*/	  
  	function button() {
  		$numargs = func_num_args();
  		switch($numargs-1) {
  		case 0: return "<input type=\"submit\" name=\"". func_get_arg(0) ."\" value=\"Submit\" />\n";
					   break;
		case 1: return "<input type=\"submit\" name=\"". func_get_arg(0) ."\" value=\"". func_get_arg(1) ."\" />\n";
						break;
		case 2: return "<input type=\"". func_get_arg(2) ."\" name=\"". func_get_arg(0) ."\" value=\"". func_get_arg(1) ."\" />\n";
						break;
		case 3: return "<input type=\"". func_get_arg(2) ."\" name=\"". func_get_arg(0) ."\" value=\"". func_get_arg(1) ."\" ". func_get_arg(3) ."/>\n";
						break;  		  		
  		}
  	}
  	
  	/**
	* This function opens a new select order with the given name.
	*
	* This function needed to be used before you use option().
	* @return string An open select tag.
	*/
  	function open_select($name) {
  		return "<select name=\"$name\">\n";  	
  	}  	
  	
   /**
   * This function close a select order.
   *
   * Always close a select order with this function. If you forget this, it properly won't work. 
   * @return string A close select tag.
   */  	
  	function close_select() {
		return "</select>\n";
  	}  	
  	
  	/**
  	* This function creates a new option field which are used within select tags.
  	*
  	* This function can handle 3 parameters. <b>You need always at least 2 parameters for the function to work!</b>
  	* @param string <b>Defines the text/label of the option field.</b>
  	* @param string <b>Defines the value which is used.</b>
  	* @param string Can be used to declare an option field to be selected.
  	* @return string A option tag with the given values.
  	*/
  	function option() {
  		$numargs = func_num_args();
  		switch($numargs-1) {
  		case 0: die("<option value=\"\">The function option() from class form does always need at least 2 parameters.</option>");
  		case 1: return "<option value=\"". func_get_arg(1) ."\">". func_get_arg(0) ."</option>\n";
  						break;
  		case 2: return "<option value=\"". func_get_arg(1) ."\" ". func_get_arg(2) .">". func_get_arg(0) ."</option>\n";
  						break;
		}
  	}
}

























?>